<?php 
class AuthorizationRequiredException extends Exception {

	function __construct(string $message){
        parent::__construct($message);
		$this->message=$message;
		$this->code=401;
	}
	
}
